load_clusters

Function load_clusters 

pub(crate) fn load_clusters(
    root: &Path,
    profile: &str,
    profile_suffix: Option<&str>,
    variables: &BTreeMap<String, String>,
) -> Result<Vec<ClusterDefinition>, ProjectError>
Load all cluster definitions from <root>/clusters/.

Returns an empty vec if clusters/ doesn’t exist (the directory is optional). If profile_suffix is provided, each cluster definition is rewritten with the suffix appended to all cluster name references (CREATE, GRANT, COMMENT).